Lancaster University's fork of the mbed BLE API. Lives on github, https://github.com/lancaster-university/BLE_API

Dependents:   microbit-dal microbit-dal microbit-ble-open microbit-dal ... more

Fork of BLE_API by Bluetooth Low Energy

Revision:
1028:9dc2ab644517
Parent:
1020:c8664d12bf10
Child:
1029:a5d0fec3b17c
--- a/ble/GattAttribute.h	Thu Dec 10 09:15:03 2015 +0000
+++ b/ble/GattAttribute.h	Thu Dec 10 09:15:03 2015 +0000
@@ -33,12 +33,10 @@
      *              The UUID to use for this attribute.
      *  @param[in]  valuePtr
      *              The memory holding the initial value.
      *  @param[in]  len
      *              The length in bytes of this attribute's value.
      *  @param[in]  maxLen
      *              The max length in bytes of this attribute's value.
-     *  @param[in]  hasVariableLen
-     *              Whether the attribute's value length changes overtime.
      *
      *  @section EXAMPLE
      *
@@ -49,27 +47,27 @@
      *
      *  @endcode
      */
-    GattAttribute(const UUID &uuid, uint8_t *valuePtr = NULL, uint16_t len = 0, uint16_t maxLen = 0, bool hasVariableLen = true) :
-        _uuid(uuid), _valuePtr(valuePtr), _lenMax(maxLen), _len(len), _hasVariableLen(hasVariableLen), _handle() {
+    GattAttribute(const UUID &uuid, uint8_t *valuePtr = NULL, uint16_t initialLen = 0, uint16_t maxLen = 0) :
+        _uuid(uuid), _valuePtr(valuePtr), _initialLen(initialLen), _lenMax(maxLen), _len(initialLen), _handle() {
         /* Empty */
     }
 
 public:
-    Handle_t    getHandle(void)         const {return _handle;        }
-    const UUID &getUUID(void)           const {return _uuid;          }
-    uint16_t    getLength(void)         const {return _len;           }
-    uint16_t    getMaxLength(void)      const {return _lenMax;        }
-    uint16_t   *getLengthPtr(void)            {return &_len;          }
-    void        setHandle(Handle_t id)        {_handle = id;          }
-    uint8_t    *getValuePtr(void)             {return _valuePtr;      }
-    bool        hasVariableLength(void) const {return _hasVariableLen;}
+    Handle_t    getHandle(void)        const {return _handle;    }
+    const UUID &getUUID(void)          const {return _uuid;      }
+    uint16_t    getLength(void)        const {return _len;       }
+    uint16_t    getInitialLength(void) const {return _initialLen;}
+    uint16_t    getMaxLength(void)     const {return _lenMax;    }
+    uint16_t   *getLengthPtr(void)           {return &_len;      }
+    void        setHandle(Handle_t id)       {_handle = id;      }
+    uint8_t    *getValuePtr(void)            {return _valuePtr;  }
 
 private:
-    UUID      _uuid;           /* Characteristic UUID. */
+    UUID      _uuid;        /* Characteristic UUID. */
     uint8_t  *_valuePtr;
-    uint16_t  _lenMax;         /* Maximum length of the value. */
-    uint16_t  _len;            /* Current length of the value. */
-    bool      _hasVariableLen;
+    uint16_t  _initialLen;  /* Initial length of the value. */
+    uint16_t  _lenMax;      /* Maximum length of the value. */
+    uint16_t  _len;         /* Current length of the value. */
     Handle_t  _handle;
 
 private:
@@ -33,12 +33,10 @@
      *  @param[in]  valuePtr
      *              The memory holding the initial value.
-     *  @param[in]  len
-     *              The length in bytes of this attribute's value.
+     *  @param[in]  initialLen
+     *              The min length in bytes of this attribute's value.
      *  @param[in]  maxLen
      *              The max length in bytes of this attribute's value.